@@ -22,11 +22,17 @@ class ClockPartsDraw : public QWidget {
   struct pImpl;
   std::auto_ptr<pImpl> pimpl;
 
+protected:
+  void paintEvent(QPaintEvent* event);
+
 public:
   explicit ClockPartsDraw(QWidget* parent = 0);
   ~ClockPartsDraw(void);
 
-  // !!!
+  /*!
+    \brief テーマ時計の再描画を行う
+  */
+  void redraw(void);
 };
 
 #endif /* !CLOCK_PARTS_DRAW_H */
