@@ -14,7 +14,11 @@
 
 struct ClockSettingDialog::pImpl {
 
-  // !!!
+  void initializeForm(ClockSettingDialog* parent) {
+
+    // 拡大率の変更
+    // !!!
+  }
 };
 
 
@@ -22,7 +26,7 @@ ClockSettingDialog::ClockSettingDialog(QDialog* parent)
   : QDialog(parent), pimpl(new pImpl) {
   setupUi(this);
 
-  // !!!
+  pimpl->initializeForm(this);
 }
 
 
@@ -30,7 +34,4 @@ ClockSettingDialog::~ClockSettingDialog(void) {
 }
 
 
-// !!! テーマのアンロードボタン
-
-
 // !!! 拡大率スライダの処理ハンドラ
