@@ -17,7 +17,7 @@
 #include "ThemeClockWidget.h"
 #include "ThemeClockDraw.h"
 #include "ClockSettingDialog.h"
-#include "ToSjisString.h"
+#include "ConvertStdStringPath.h"
 
 using namespace qrk;
 
@@ -265,8 +265,8 @@ void ThemeClockWidget::dropEvent(QDropEvent* event) {
     // 先頭の '/' を取り除く
     path.replace(0, 1, "");
 
-    // 日本語ロケールの場合、文字列を SJIS に変換する (Windows XP 用)
-    path = toSjisString(path);
+    // 日本語のパスを含む場合への対処
+    path = toStdStringPath(path);
 
     if (pimpl->loadThemeFile(path, this)) {
       return;
