@@ -1,22 +1,12 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS><TS version="1.1" language="ja_JP">
-<defaultcodec>ISO-8859-5</defaultcodec>
+<defaultcodec></defaultcodec>
 <context>
     <name>@default</name>
     <message>
-        <location filename="ThemeClockDraw.cpp" line="29"/>
-        <source>Drop theme file in this form.</source>
-        <translation type="obsolete">テーマファイルを、このフォームにドロップして下さい。</translation>
-    </message>
-    <message>
-        <location filename="ThemeClockWidget.cpp" line="118"/>
-        <source>E&amp;xit</source>
-        <translation type="obsolete">終了&amp;x</translation>
-    </message>
-    <message>
-        <location filename="ThemeClockWidget.cpp" line="156"/>
+        <location filename="ThemeClockWidget.cpp" line="157"/>
         <source>Ctrl+Q</source>
-        <translation>Ctrl-Q</translation>
+        <translation>Ctrl+Q</translation>
     </message>
 </context>
 <context>
@@ -44,7 +34,7 @@
     <message>
         <location filename="ClockSettingDialogForm.ui" line="104"/>
         <source>Unload</source>
-        <translation>アンロ＝ド</translation>
+        <translation>アンロード</translation>
     </message>
     <message>
         <location filename="ClockSettingDialogForm.ui" line="98"/>
@@ -75,12 +65,12 @@
 <context>
     <name>QAction</name>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="155"/>
+        <location filename="ThemeClockWidget.cpp" line="156"/>
         <source>E&amp;xit</source>
         <translation>終了(&amp;x)</translation>
     </message>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="150"/>
+        <location filename="ThemeClockWidget.cpp" line="151"/>
         <source>Config</source>
         <translation>設定</translation>
     </message>
@@ -88,7 +78,7 @@
 <context>
     <name>QLabel</name>
     <message>
-        <location filename="ThemeClockDraw.cpp" line="60"/>
+        <location filename="ThemeClockDraw.cpp" line="59"/>
         <source>Drop theme file in this form.</source>
         <translation>テーマファイルを、このフォームにドロップして下さい。</translation>
     </message>
@@ -96,12 +86,12 @@
 <context>
     <name>ThemeClockWidget</name>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="275"/>
+        <location filename="ThemeClockWidget.cpp" line="276"/>
         <source>qtmclock</source>
         <translation>qtmclock</translation>
     </message>
     <message>
-        <location filename="ThemeClockWidget.cpp" line="276"/>
+        <location filename="ThemeClockWidget.cpp" line="277"/>
         <source>%1 is not correct theme file.</source>
         <translation>%1 はテーマファイルではありません。</translation>
     </message>
