@@ -5,6 +5,8 @@
   \author Satofumi KAMIMURA
 
   $Id$
+
+  \todo ディレクトリ名を除去する関数を作成し、くくる
 */
 
 #include <QHeaderView>
@@ -19,7 +21,7 @@
 #include "SettingConfig.h"
 #include "ReleaseDialog.h"
 #include "ReleaseDataFile.h"
-#include "ToSjisString.h"
+#include "ConvertStdStringPath.h"
 
 using namespace qrk;
 
@@ -95,11 +97,12 @@ struct ThemeConfigWindow::pImpl {
   PositionMap parts_positions_;
 
   ReleaseDialog release_dialog_;
+  std::string work_dir_;
 
   pImpl(void)
     : new_act_(NULL), open_act_(NULL), save_act_(NULL),
       archive_config_(NULL), setting_config_(NULL), save_ok_(false),
-      same_hands_center_(false), scene_(NULL) {
+      same_hands_center_(false), scene_(NULL), work_dir_(".") {
   }
 
 
@@ -283,15 +286,21 @@ struct ThemeConfigWindow::pImpl {
 
 
   // 設定ファイルオブジェクトの生成
-  void loadArchiveFile(ThemeConfigWindow* parent, const char* name) {
+  void loadArchiveFile(ThemeConfigWindow* parent, const std::string& name) {
 
-    QFileInfo fi(name);
-    std::string absolute_path = fi.absoluteFilePath().toStdString();
+    ArchiveConfig* archive_config = NULL;
+    if (name.empty()) {
+      archive_config = new ArchiveConfig("");
+    } else {
+      QFileInfo fi(name.c_str());
+      std::string absolute_path = fi.absoluteFilePath().toStdString();
+      archive_config = new ArchiveConfig(absolute_path);
+    }
 
-    ArchiveConfig* archive_config = new ArchiveConfig(absolute_path);
     std::swap(archive_config, archive_config_);
     delete archive_config;
 
+    work_dir_ = archive_config_->getReleaseDirectoryName();
     const std::string xml_file = archive_config_->getNormalData("config");
     const std::string adjusted_xml_file = xml_file.empty() ? "" : xml_file;
     SettingConfig* setting_config = new SettingConfig(adjusted_xml_file);
@@ -368,7 +377,7 @@ struct ThemeConfigWindow::pImpl {
     delete pixmaps_.value(tag, NULL);
     delete icons_.value(tag, NULL);
 
-    QPixmap* pixmap = new QPixmap(name.c_str());
+    QPixmap* pixmap = new QPixmap(fromStdStringPath(name));
     pixmaps_[tag] = pixmap;
 
     QIcon* icon = new QIcon(*pixmap);
@@ -377,7 +386,7 @@ struct ThemeConfigWindow::pImpl {
     // ツリーアイテムの更新
     name_to_item_[tag]->setIcon(1, *icon);
 
-    size_t dir_length = archive_config_->getReleaseDirectoryName().size();
+    size_t dir_length = work_dir_.size();
     const std::string set_name = name.substr(dir_length, std::string::npos);
     name_to_item_[tag]->setText(1, set_name.c_str());
 
@@ -707,14 +716,18 @@ struct ThemeConfigWindow::pImpl {
   }
 
 
-  // 登録していある名前を変更し、画像を更新する
-  void updateItemName(const QString& fileName) {
+  // 登録してある名前を変更し、画像を更新する
+  void updateItemName(ThemeConfigWindow* parent, const QString& fileName) {
 
     const std::string archive_tag = setting_config_->getValue(current_tag_);
-    archive_config_->setNormalData(archive_tag, fileName.toStdString());
+    size_t dir_length = work_dir_.size();
+    const std::string set_name =
+      fileName.toStdString().substr(dir_length, std::string::npos);
+    archive_config_->setNormalData(archive_tag, set_name);
 
     loadImage(current_tag_.c_str());
     updateItems();
+    setSaveEnabled(parent, true);
   }
 };
 
@@ -763,7 +776,7 @@ ThemeConfigWindow::ThemeConfigWindow(const QString& config_file)
 
   // ファイルが指定されていれば、読み出し
   if (! config_file.isEmpty()) {
-    pimpl->loadArchiveFile(this, config_file.toStdString().c_str());
+    pimpl->loadArchiveFile(this, config_file.toStdString());
     pimpl->setSaveEnabled(this, false);
   }
 
@@ -800,14 +813,15 @@ void ThemeConfigWindow::newFile(void) {
 void ThemeConfigWindow::openFile(void) {
 
   QString fileName =
-    QFileDialog::getOpenFileName(this, tr("Open archive list file."), ".",
+    QFileDialog::getOpenFileName(this, tr("Open archive list file."),
+				 fromStdStringPath(pimpl->work_dir_.c_str()),
                                  tr("archive list (*.txt)"));
 
   if (! fileName.isEmpty()) {
     // 日本語のパスを含む場合への対処
-    fileName = toSjisString(fileName);
+    fileName = toStdStringPath(fileName);
 
-    pimpl->loadArchiveFile(this, fileName.toStdString().c_str());
+    pimpl->loadArchiveFile(this, fileName.toStdString());
     pimpl->setSaveEnabled(this, false);
   }
 }
@@ -835,12 +849,13 @@ void ThemeConfigWindow::saveFile(void) {
 void ThemeConfigWindow::saveFileAs(void) {
 
   QString fileName =
-    QFileDialog::getSaveFileName(this, tr("Save archive list file."), ".",
+    QFileDialog::getSaveFileName(this, tr("Save archive list file."),
+				 fromStdStringPath(pimpl->work_dir_.c_str()),
                                  tr("archive list (*.txt)"));
 
   if (! fileName.isEmpty()) {
     // 日本語のパスを含む場合への対処
-    fileName = toSjisString(fileName);
+    fileName = toStdStringPath(fileName);
 
     pimpl->save(this, fileName.toStdString().c_str());
   }
@@ -851,7 +866,7 @@ void ThemeConfigWindow::saveFileAs(void) {
 void ThemeConfigWindow::releaseData(void) {
 
   // リリース名、キー値の設定
-  size_t base_length = pimpl->archive_config_->getReleaseDirectoryName().size();
+  size_t base_length = pimpl->work_dir_.size();
   const std::string name = pimpl->archive_config_->getReleaseName();
   const std::string key = pimpl->archive_config_->getRrdaKey();
   pimpl->release_dialog_.
@@ -1004,7 +1019,7 @@ void ThemeConfigWindow::downPressed(void) {
 // 部品画像の更新、文字列入力
 void ThemeConfigWindow::partsEditHandler(void) {
 
-  pimpl->updateItemName(image_lineedit_->text());
+  pimpl->updateItemName(this, image_lineedit_->text());
 }
 
 
@@ -1012,14 +1027,15 @@ void ThemeConfigWindow::partsEditHandler(void) {
 void ThemeConfigWindow::updateHandlelr(void) {
 
   QString fileName =
-    QFileDialog::getOpenFileName(this, tr("Open parts file."), ".",
+    QFileDialog::getOpenFileName(this, tr("Open parts file."),
+				 fromStdStringPath(pimpl->work_dir_.c_str()),
                                  tr("parts file (*.png)"));
 
   if (! fileName.isEmpty()) {
     // 日本語のパスを含む場合への対処
-    fileName = toSjisString(fileName);
+    fileName = toStdStringPath(fileName);
 
-    pimpl->updateItemName(fileName.toStdString().c_str());
+    pimpl->updateItemName(this, fileName);
   }
 }
 
